Magnetic Field
========================

H-field calculation:

The magenetic field is calculated analytically using the Biot-Savart formula.

.. image:: helpdocs/equations/radius_b_field.png
.. image:: helpdocs/equations/h_field_x.png
.. image:: helpdocs/equations/h_field_y.png
.. image:: helpdocs/equations/h_field.png

B-field calculation:

The quantity that is shown on the graph as the magnetic field is actually the
magnetic flux density.

.. image:: helpdocs/equations/b_field.png
